==> event-queue-0.1.56.tgz: package/README.md <==
# @cap-js-community/event-queue

[![npm version](https://img.shields.io/npm/v/@cap-js-community/event-queue)](https://www.npmjs.com/package/@cap-js-community/event-queue)
[![monthly downloads](https://img.shields.io/npm/dm/@cap-js-community/event-queue)](https://www.npmjs.com/package/@cap-js-community/event-queue)
[![REUSE status](https://api.reuse.software/badge/github.com/cap-js-community/event-queue)](https://api.reuse.software/info/github.com/cap-js-community/event-queue)
[![CI Main](https://github.com/cap-js-community/event-queue/actions/workflows/ci-main.yml/badge.svg)](https://github.com/cap-js-community/event-queue/commits/main)

The Event-Queue is a framework built on top of CAP Node.js, specifically designed to enable efficient and streamlined
asynchronous event processing in a multi-tenancy environment. With a strong emphasis on load balancing, this package
ensures optimal distribution of workload across all available application instances. By offering managed tenant-specific
transactions, similar to CAP handlers, the Event-Queue framework simplifies event and asynchronous processing, thereby
enhancing the overall performance of your application.

## Getting started

- Run `npm add @cap-community/event-queue` in `@sap/cds` project
- Activate the cds-plugin in the cds section of the package.sjon

### As cds-plugin

Extend the cds section of your package.json. Reference to the cds-plugin section in the capire documentation about the
cds-plugin concept.
https://cap.cloud.sap/docs/releases/march23#new-cds-plugin-technique

```json
{
  "cds": {
    "eventQueue": {
      "plugin": true,
      "configFilePath": "./srv/eventQueueConfig.yml"
    }
  }
}
```

## Features

- load balancing of event processing throughout app instances
- control concurrency in app instances
- managed transactions for event processing
- async processing of processing intensive tasks for better UI responsiveness
- push/pull mechanism for reducing delay between publish an event and processing
- cluster published events during processing (e.g. for combining multiple E-Mail events to one E-Mail)
- plug and play via cds-plugin

## Documentation

Head over to our [Documentation](https://cap-js-community.github.io/event-queue/) to learn more.

## Support, Feedback, Contributing

This project is open to feature requests/suggestions, bug reports etc.
via [GitHub issues](https://github.com/cap-js-community/<your-project>/issues). Contribution and feedback are encouraged
and always welcome. For more information about how to contribute, the project structure, as well as additional
contribution information, see our [Contribution Guidelines](CONTRIBUTING.md).

## Code of Conduct

We as members, contributors, and leaders pledge to make participation in our community a harassment-free experience for
everyone. By participating in this project, you agree to abide by its [Code of Conduct](CODE_OF_CONDUCT.md) at all
times.

## Licensing

Copyright 2023 SAP SE or an SAP affiliate company and `@cap-js-community/event-queue contributors`. Please see
our [LICENSE](LICENSE) for copyright and license information. Detailed information including third-party components and
their licensing/copyright information is
available [via the REUSE tool](https://api.reuse.software/info/github.com/cap-js-community/<your-project>).

==> event-queue-0.1.57.tgz: package/README.md <==
# @cap-js-community/event-queue

[![npm version](https://img.shields.io/npm/v/@cap-js-community/event-queue)](https://www.npmjs.com/package/@cap-js-community/event-queue)
[![monthly downloads](https://img.shields.io/npm/dm/@cap-js-community/event-queue)](https://www.npmjs.com/package/@cap-js-community/event-queue)
[![REUSE status](https://api.reuse.software/badge/github.com/cap-js-community/event-queue)](https://api.reuse.software/info/github.com/cap-js-community/event-queue)
[![CI Main](https://github.com/cap-js-community/event-queue/actions/workflows/ci-main.yml/badge.svg)](https://github.com/cap-js-community/event-queue/commits/main)

The Event-Queue is a framework built on top of CAP Node.js, specifically designed to enable efficient and streamlined
asynchronous event processing in a multi-tenancy environment. With a strong emphasis on load balancing, this package
ensures optimal distribution of workload across all available application instances. By offering managed tenant-specific
transactions, similar to CAP handlers, the Event-Queue framework simplifies event and asynchronous processing, thereby
enhancing the overall performance of your application.

## Getting started

- Run `npm add @cap-js-community/event-queue` in `@sap/cds` project
- Activate the cds-plugin in the cds section of the package.sjon

### As cds-plugin

Extend the cds section of your package.json. Reference to the cds-plugin section in the capire documentation about the
cds-plugin concept.
https://cap.cloud.sap/docs/releases/march23#new-cds-plugin-technique

```json
{
  "cds": {
    "eventQueue": {
      "plugin": true,
      "configFilePath": "./srv/eventQueueConfig.yml"
    }
  }
}
```

## Features

- load balancing of event processing throughout app instances
- control concurrency in app instances
- managed transactions for event processing
- async processing of processing intensive tasks for better UI responsiveness
- push/pull mechanism for reducing delay between publish an event and processing
- cluster published events during processing (e.g. for combining multiple E-Mail events to one E-Mail)
- plug and play via cds-plugin

## Documentation

Head over to our [Documentation](https://cap-js-community.github.io/event-queue/) to learn more.

## Support, Feedback, Contributing

This project is open to feature requests/suggestions, bug reports etc.
via [GitHub issues](https://github.com/cap-js-community/<your-project>/issues). Contribution and feedback are encouraged
and always welcome. For more information about how to contribute, the project structure, as well as additional
contribution information, see our [Contribution Guidelines](CONTRIBUTING.md).

## Code of Conduct

We as members, contributors, and leaders pledge to make participation in our community a harassment-free experience for
everyone. By participating in this project, you agree to abide by its [Code of Conduct](CODE_OF_CONDUCT.md) at all
times.

## Licensing

Copyright 2023 SAP SE or an SAP affiliate company and `@cap-js-community/event-queue contributors`. Please see
our [LICENSE](LICENSE) for copyright and license information. Detailed information including third-party components and
their licensing/copyright information is
available [via the REUSE tool](https://api.reuse.software/info/github.com/cap-js-community/<your-project>).
